@@ -1,7 +1,8 @@
 #!/usr/bin/python2.5
-# versione 1.6
+# versione 1.7
 # ui di configurazione per savepu
 # by m750 at smartphonetab.net
+# patch for v50 by peter leinchen
 
 import sys
 import osso
@@ -13,7 +14,7 @@ from PyQt4.QtCore import *
 from savecpu_ui import *
 
 
-Global_Version = '2.20.16-1'
+Global_Version = '2.21.17-1'
 UI_Version = '1.5'
 
 try:
@@ -187,23 +188,26 @@ class MyForm(QtGui.QMainWindow):
 
                 time.sleep(0.1)
                 #temperatura = os.popen('cat /sys/class/power_supply/bq27200-0/temp').read()
-                temperatura = os.popen('cat /sys/devices/platform/omap34xx_temp/temp1_input').read()
+                ###temperatura = os.popen('cat /sys/devices/platform/omap34xx_temp/temp1_input').read()
+                temperatura = os.popen('echo $(sudo i2cget -y 2 0x55 0x06 w) | awk \'{ printf ($1*0.25-273)*100 }\'').read()
                 # kernel v47
-                #print temperatura
+                print temperatura
                 #temperatura=temperatura.strip()
                 #print temperatura
                 #if len(temperatura) == 3 :
                 #    temperatura = int(temperatura) / 10
-                temperatura = int(temperatura) + 7
+                ###temperatura = int(temperatura) + 7
+                temperatura = (int(temperatura) + 50) / 100
 
                 temperatura=str(temperatura)    
-                #print temperatura
+                print temperatura
 
 
 
 
 
-                check = os.popen('ps -ef | grep /opt/savecpu/savecpu.sh | awk \'/start/ {print $7}\'').read()
+                ###check = os.popen('ps -ef | grep /opt/savecpu/savecpu.sh | awk \'/start/ {print $7}\'').read()
+                check = os.popen('ps -ef | grep /opt/savecpu/savecpu.sh | awk \'/start/ {print $8}\'').read()
                 check=check.strip()
 
                 #print check
